@@ -9,4 +9,4 @@
 
 . ./include.sh
 
-${examples_dir}set > /dev/null
+${examples_dir}f_set > /dev/null
