@@ -9,4 +9,4 @@
 
 . ./include.sh
 
-${examples_dir}set_pv > /dev/null
+${examples_dir}f_set_pv > /dev/null
