@@ -167,7 +167,6 @@ static void init(grib_accessor* a,const long v, grib_arguments* args)
     self->decimal_scale_factor = grib_arguments_get_name(a->parent->h,args,self->carg++);
     a->flags |= GRIB_ACCESSOR_FLAG_DATA;
     self->dirty=1;
-
 }
 
 static unsigned long nbits[32]={
@@ -179,10 +178,15 @@ static unsigned long nbits[32]={
         0x40000000, 0x80000000
 };
 
-GRIB_INLINE static long number_of_bits(unsigned long x) {
+static long number_of_bits(unsigned long x) {
     unsigned long *n=nbits;
+    const int count = sizeof(nbits)/sizeof(nbits[0]);
     long i=0;
-    while (x>=*n) {n++;i++;}
+    while (x>=*n) {
+        n++;
+        i++;
+        Assert(i<count);
+    }
     return i;
 }
 
@@ -196,7 +200,6 @@ static long value_count(grib_accessor* a){
         return 0;
 
     return number_of_values;
-
 }
 
 static int  unpack_double_element(grib_accessor* a, size_t idx, double* val)
@@ -286,7 +289,6 @@ static int  unpack_double_element(grib_accessor* a, size_t idx, double* val)
             lvalue |= buf[o++] ;
         }
         *val = (double) (((lvalue*s)+reference_value)*d);
-
     }
 
     return err;
@@ -308,7 +310,6 @@ static int  _unpack_double(grib_accessor* a, double* val, size_t *len,unsigned c
     double units_factor=1.0;
     double units_bias=0.0;
 
-
     if(*len < n_vals)
     {
         *len = (long) n_vals;
@@ -422,7 +423,6 @@ static int  unpack_double(grib_accessor* a, double* val, size_t *len) {
     return _unpack_double(a,val,len,buf,pos,nvals);
 }
 
-
 static int pack_double(grib_accessor* a, const double* val, size_t *len)
 {
     grib_accessor_data_simple_packing* self =  (grib_accessor_data_simple_packing*)a;
@@ -638,7 +638,5 @@ static int pack_double(grib_accessor* a, const double* val, size_t *len)
             != GRIB_SUCCESS)
         return err;
 
-
     return GRIB_SUCCESS;
-
 }
