@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2013 ECMWF.
+ * Copyright 2005-2014 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -455,6 +455,7 @@ second_order_packed *grib_get_second_order_groups(grib_context *c, const unsigne
 /* grib_accessor_class_local_definition.c */
 
 /* grib_accessor_class_g2_eps.c */
+/* grib_accessor_class_g2_chemical.c */
 
 /* grib_accessor_class_g2_mars_labeling.c */
 
@@ -464,13 +465,10 @@ second_order_packed *grib_get_second_order_groups(grib_context *c, const unsigne
 int grib_jasper_decode(grib_context *c, unsigned char *buf, size_t *buflen, double *values, size_t *no_values);
 int grib_jasper_encode(grib_context *c, j2k_encode_helper *helper);
 int grib_jasper_decode(grib_context *c, unsigned char *buf, size_t *buflen, double *val, size_t *n_vals);
-int grib_jasper_encode(grib_context *c, j2k_encode_helper *helper);
 
 /* grib_openjpeg_encoding.c */
 int grib_openjpeg_encode(grib_context *c, j2k_encode_helper *helper);
 int grib_openjpeg_decode(grib_context *c, unsigned char *buf, size_t *buflen, double *val, size_t *n_vals);
-int grib_openjpeg_decode(grib_context *c, unsigned char *buf, size_t *buflen, double *val, size_t *n_vals);
-int grib_openjpeg_encode(grib_context *c, j2k_encode_helper *helper);
 
 /* action_class_set_missing.c */
 grib_action *grib_action_create_set_missing(grib_context *context, const char *name);
@@ -577,14 +575,6 @@ void grib_timer_print(grib_timer *t);
 void grib_timer_partial_rate(grib_timer *t, double start, long total);
 void grib_print_all_timers(void);
 void grib_reset_all_timers(void);
-grib_timer *grib_get_timer(grib_context *c, const char *name, const char *statname, int elapsed);
-int grib_timer_start(grib_timer *t);
-int grib_timer_stop(grib_timer *t, long total);
-double grib_timer_value(grib_timer *t);
-void grib_timer_print(grib_timer *t);
-void grib_timer_partial_rate(grib_timer *t, double start, long total);
-void grib_print_all_timers(void);
-void grib_reset_all_timers(void);
 
 /* grib_ibmfloat.c */
 unsigned long grib_ibm_to_long(double x);
@@ -603,15 +593,10 @@ double grib_ieeefloat_error(double x);
 double grib_long_to_ieee(unsigned long x);
 unsigned long grib_ieee_nearest_smaller_to_long(double x);
 int grib_nearest_smaller_ieee_float(double a, double *ret);
-double grib_ieeefloat_error(double x);
-double grib_long_to_ieee(unsigned long x);
-int grib_nearest_smaller_ieee_float(double a, double *x);
-unsigned long grib_ieee_to_long(double x);
+
 unsigned long grib_ieee64_to_long(double x);
 double grib_long_to_ieee64(unsigned long x);
 int grib_ieee_decode_array(grib_context *c, unsigned char *buf, size_t nvals, int bytes, double *val);
-int grib_ieee_decode_array(grib_context *c, unsigned char *buf, size_t nvals, int bytes, double *val);
-int grib_ieee_encode_array(grib_context *c, double *val, size_t nvals, int bytes, unsigned char *buf);
 int grib_ieee_encode_array(grib_context *c, double *val, size_t nvals, int bytes, unsigned char *buf);
 
 /* grib_accessor_class_reference_value_error.c */
@@ -879,7 +864,6 @@ long grib_get_decimal_scale_fact(double max, double min, long bpval, long binary
 
 /* grib_templates.c */
 grib_handle *grib_internal_template(grib_context *c, const char *name);
-grib_handle *grib_internal_template(grib_context *c, const char *name);
 grib_handle *grib_external_template(grib_context *c, const char *name);
 char *grib_external_template_path(grib_context *c, const char *name);
 
@@ -1071,6 +1055,9 @@ grib_string_list *grib_util_get_mars_param(const char *param_id);
 grib_handle *grib_util_set_spec(grib_handle *h, const grib_util_grid_spec *spec, const grib_util_packing_spec *packing_spec, int flags, const double *data_values, size_t data_values_count, int *err);
 int grib_moments(grib_handle *h, double east, double north, double west, double south, int order, double *moments, long *count);
 int parse_keyval_string(char* grib_tool, char* arg, int values_required, int default_type, grib_values values[], int* count);
+int is_productDefinitionTemplateNumber_EPS(long productDefinitionTemplateNumber);
+int is_productDefinitionTemplateNumber_Chemical(long productDefinitionTemplateNumber);
+int is_productDefinitionTemplateNumber_Aerosol(long productDefinitionTemplateNumber);
 
 /* compile.c */
 void grib_compile_flags(grib_compiler *c, long flags);
